@@ -187,6 +187,7 @@
 /* O */
 #define ICON_EXT_O         ICON_MANUAL
 #define ICON_EXT_OGG       ICON_MUSICFILE
+#define ICON_EXT_OPUS      ICON_MUSICFILE
 #define ICON_EXT_ODOWNLOAD ICON_DOWNLOADS
 #define ICON_EXT_OUT       ICON_LINUX
 
@@ -250,6 +251,7 @@
 /* W */
 #define ICON_EXT_WAV       ICON_MUSICFILE
 #define ICON_EXT_WEBM      ICON_VIDEOFILE
+#define ICON_EXT_WEBP      ICON_PICTUREFILE
 #define ICON_EXT_WMA       ICON_VIDEOFILE
 #define ICON_EXT_WMV       ICON_VIDEOFILE
 
